Wallex-python v.0.0.6
===========================================================

## Wallex Python SDK
This is an unofficial Python wrapper for the `Wallex exchange API v1 <https://api-docs.wallex.ir>`. use at your own risk.

Source code
  https://github.com/wallexchange/wallex-python

Documentation
  https://api-docs.wallex.ir/

## Installation

```bash
pip install wallex-python --save
```

## Usage

```python
from wallex.client import Client

client = Client(api_key='YOUR_API_KEY')
```

## License

[![wallex-python](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)


## Contributing

![wallex-python](https://img.shields.io/badge/contributing-guide-blue.svg)


## Tests

```bash
python -m pytest
```


## Changelog

```bash
git log --pretty=format:'%h - %an, %ar : %s' --graph
```


## Contributors

```bash
git shortlog -sn
```